      program hurrtest_fortran
c
c  Define the minimum data needed to initialize and run a 3-D numerical
c  ocean model of the response to a hurricane:
c
c  1) Specify the profiles of T(z) and S(z) that are be used
c  to initialize an ocean model. The data hardwired in here
c  were taken from EMAEX data observed approx one day before the
c  passage of hurricane Frances through the CBLAST region in 2004. 
c
c  2) Define a hurricane wind and stress field. These important data
c  are thanks to HWINDS of AOML/HRD. 
c
c  These data are written to files and can be plotted by the Matlab script 
c  plotFrancesICandtau.m, though the file names will probably depend upon your 
c  Fortan compiler.
c
c  Version 4.0
c  by Jim Price, Jan, 2007.  Please let me know if you have questions.
c  508-289-2526, jprice@whoi.edu.
c
c
c  define the dimensions of the model grid;  .
c
      parameter (nx=61, ny=61, nz=45)   
c
c  these arrays store the hurricane stress, etc.
c
      dimension taux(ny, nx), tauy(ny, nx), aspd(ny, nx), 
     x u(nx, ny), v(nx, ny),  adew(ny, nx), adry(ny, nx)                                       
c,
c  these arrays store the initial T, S
c
      dimension zob(15), sob(15), tob(15)   !  observed T,S,Z data
      dimension tinit(50), sinit(50)
c
c  these arrays are model coordinates
c
      dimension x(nx), y(ny), xoc(ny, nx), yoc(ny, nx)
      dimension z(nz), dz(nz)
c
c   for the HWinds data
c
      parameter (nxhw = 161,	nyhw = 161)
      dimension xhw(nyhw, nxhw), yhw(nyhw, nxhw), uhw(nyhw, nxhw), 
     c  vhw(nyhw, nxhw),  x1hw(nxhw), y1hw(nyhw)
c
c  open the disk files needed to store the output
c
      open(unit=10, file='TSinitprofiles.dat')
	open(unit=2, file='stressfield.dat')
c
c  set the ocean initial condition, the  z, t, s profiles.	                                
c  these initial temperature and salinity are from EM-APEX
c  above 200 m and climatology below
c
	data zob/0., 20., 30., 40., 50., 60., 80., 100., 150., 
     c 200., 300., 500., 1000., 2000., 5000./
c
	data tob/29.3, 29.3, 29.3, 29.0, 28.0, 27.0, 26.3,  25.5, 23.3,    
     c 21., 17., 15., 6.5, 3.6, 3.0/
c
	data sob/36.2, 36.2, 36.5, 36.6, 36.8, 36.85, 37.05, 37.05, 37.0, 
     c36.9, 36.75, 35.8, 35.2, 35.0, 35.0/ 
c
      nts = 15     !  the actual number of points in the arrays above   
c
c  interpolate the initial data to get a profile at dz resolution.
c  the vertical resolution is dzuo over the shallowest nz1 points
c   "            25 m over nz1+1 thru nz2
c   "           100 m over nz2+1 thru nz
c
      dzuo = 10.
      nz1 = 20
      nz2 = 30
c
      do 542 j=1,nz
      dz(j) = dzuo
      if(j.gt.nz1) dz(j) = 25.
      if(j.gt.nz2) dz(j) = 100.
c      
      z(1) = dzuo/2. 
      if(j.gt.1) z(j) = z(j-1) + dz(j) 
      call lintrp(zob,tob,nts,z(j),tinit(j))
      call lintrp(zob,sob,nts,z(j),sinit(j))
  542 continue
c
c  write these data to fortran unit 1 
c
      do 18 m=1,nz
      write (10,594) z(m), tinit(m), sinit(m)
  594 format (6f12.5)   
   18 continue
c
c  initialization of T,S is finished.
c  
c
c  now read in and rearrange as neeede the HWINDS data set
c                                                                          
      ncx = nx/2 + 1    
      ncy = ny/2 + 1
c
c  set the grid interval, km,  on which to evaluate the hurricane stress
c	 
      dx = 10.     
	dy = dx
c
c  the along-track coordinate, y, fixed in the ocean, increases in the direction  
c  that the hurricane is moving
c
      do 500 k=1,ny 
      y(k) = dy*float(k-ncy) + .1
  500 continue
c
c  the across-track coordinate
c
      do 501 j=1,nx                                                   
      x(j) = dx*float(j-ncx)  + .1                                       
  501 continue
c
c  read in the HWINDS wind field
c
      open(unit=50, file = 'HW_01Sep.dat', status = 'old')
c
      alonc = -70.42;
      alatc = 21.78;
c
      do 1076 i=1,nyhw
	do 976 j=1,nxhw
c
	read(50, *) alonhw, alathw, uhw(i,j), vhw(i,j)
   12 format (4f15.5)
c
      dlonhw = alonhw - alonc
	dlathw = alathw - alatc
c
	xhw(i,j) = dlonhw*111.3*cos(alatc*3.1415/180.)
	yhw(i,j) = dlathw*111.3
c
  976 continue
 1076 continue
      do 2075 i=1,161
	x1hw(i) = xhw(1,i)
	y1hw(i) = yhw(i,1)
	write (6, 2275) x1hw(i), y1hw(i), uhw(80, i), uhw(i, 80), 
     c vhw(80, i), vhw(i, 80)
 2275 format (1x, 6f12.2)
 2075 continue 
c                                                                               
c  compute the wind and wind stress fields
c
c  run through the ocean grid, specifying the stress components at each point
c
      do 5 j=1,nx
      do 5 k=1,ny
      xoc(k,j) = x(j)  ! these coordinates are along and across track
      yoc(k,j) = y(k)
c	
c  rotate this x, y to find the north/south x, y used by HWINDS,
c  which is in a lat, lon coordinates, not storm centered
c          as needed here
c
      ang9 = 70.     !  the angle of Frances's track wrt north
      ang = -ang9*3.14159/180.
	xr = (xoc(k,j)*cos(ang) + yoc(k,j)*sin(ang))      
	yr = ((-xoc(k,j)*sin(ang)) + yoc(k,j)*cos(ang)) 
c
      call hurrihw(uhw, vhw, x1hw, y1hw, xr, yr, 
     x              u(k,j), v(k,j), taux(k,j), tauy(k,j))     
c 
c  now rotate the wind and wind stress components: 
c
      ang = ang9*3.14159/180.
	ur = (u(k,j)*cos(ang) + v(k,j)*sin(ang))      
	vr = ((-u(k,j)*sin(ang)) + v(k,j)*cos(ang))  
	u(k,j) = ur
	v(k,j) = vr
	txr = (taux(k,j)*cos(ang) + tauy(k,j)*sin(ang))      
	tyr = ((-taux(k,j)*sin(ang)) + tauy(k,j)*cos(ang)) 
	taux(k,j) = txr
	tauy(k,j) = tyr
c
	write (6,102) j, k, xoc(k,j), yoc(k,j), taux(k,j), tauy(k,j)
  102 format (1x, '  j, k', 2i9, 4f10.1)
c
    5 continue
c
c  write the wind and stress data to fortran file 2 
c
      do 9 k=1,ny
	do 9 j=1,nx
      write (2,99) xoc(k,j), yoc(k,j), u(k,j), v(k,j),
     c  taux(k,j), tauy(k,j) 
    9 continue
   99 format (6f15.4)
c
c
      stop 
	end
c
c
      subroutine hurrihw(uhw, vhw, xhw, yhw, xr, yr, u, v, taux, tauy) 
c
c  this subroutine specifies the hurricane wind stress
c  as a function of the position wrt the storm center, x, y 
c  taux, tauy are the estimated stress,  Pa
c
c  uhw, vhw are 2-d arrays of known wind speed components;
c  these come from HWINDS, a product of AOML/HRD. 
c  xhw and yhw are 1-d arrays of the distance from the storm center
c  these coordinates are north/south, not storm-centered
c
      dimension uhw(161,161), vhw(161, 161), xhw(161), yhw(161)
      dimension vs(14),vsr(14)
      dimension phi(5),phir(5)
c
c the Powell et al. (2003) drag coefficient as a function of U10
c Note: these data were extended somewhat to larger wind speed than
c Powell reported, approx 50 m/sec, to avoid errors in the interpolation.
c
	dimension U10p(8), Cdp(8)
      data Cdp/0.4, 1.0, 1.2, 1.8, 2.2, 2.0, 1.6, 1.6/
	data U10p/ 0., 10., 20., 28., 33., 40., 50., 70./
	data nmp/8/
c
c  the Donelan et al drag coefficient;  same comment.
c
      dimension U10d(10), Cdd(10)
	data Cdd/1.0, 0.6, 0.8, 1.3, 2.05, 2.3, 2.3, 2.3, 2.3, 2.3/
	data U10d/0., 4., 10., 20., 30., 33., 40., 50., 60., 70./ 
	data nd/10/  
c
c  use the HWINDS field directly

	call twotrp(uhw, 161, 161, xhw, yhw, xr, yr, u)
	call twotrp(vhw, 161, 161, xhw, yhw, xr, yr, v)
c
      write (6, 888) xr, yr, u, v
  888 format (1x, '  xr, yr, u, v', 4f10.2)
c        
      aspd = sqrt(u**2 + v**2)
c
c  now you have to compute the Cd;  select which Cd with a flag, 
c  one of which has to be set to 1  
c  the default should be Ipowell = 1
c
      Ilargepond = 0     
	Idonelan = 0
	Ipowell = 1
c
c                                                  
c  drag coefficient is computed according to Large and Pond
c  for hurricane wind speeds this will require an extrapolation
c  to much higher wind speeds that LandP ever intended
c
      if (Ilargepond.eq.1) then
      cd = (0.5 + .06*aspd)*1.e-3  
	end if
c
c  Donelan et al. (2004) Cd
c
      if (Idonelan.eq.1) then
	call lintrp(U10d, Cdd, nd, aspd, cd)
	cd = cd*1.e-3
	end if
c
c  Powell et al (2003) Cd
c
      if (Ipowell.eq.1) then
	call lintrp(U10p, Cdp, nmp, aspd, cd)
	cd = cd*1.e-3
	end if
c 
c  now compute the wind stress
c   
      rhoair = 1.2                                       
      taux = rhoair*cd*aspd*u
      tauy = rhoair*cd*aspd*v 
c                                                                           
    5 continue 
c
      return
      end                                                                                                         c
c
      subroutine lintrp(r, s, n, ri, si)
c
c  do a linear interpolation if withinn the bounds of the obsrved data
c
      dimension r(500), s(500)
      nm = n - 1
      do 2 k=1,nm
      if(ri.le.r(k+1).and.ri.gt.r(k)) go to 1
    2 continue
      write (6,3) r(1),r(n),ri
    3 format (1x,'times are bad in interp; rf,rl,ri',3e12.5)
      return
    1 continue
      si = (s(k)*(r(k+1) - ri) + s(k+1)*(ri - r(k)))/(r(k+1) - r(k))
      return
      end
c                                                                   
      subroutine rhot(ang,x,y)
c
c  rotate x,y into a new coordinate system which
c  is at an angle ang to old system (radians, ccw > 0)
c
      ct = cos(ang)
      st = sin(ang)
      xs = x
      ys = y
      x = xs*ct + st*ys
      y = ys*ct - st*xs
      return
      end
      SUBROUTINE TWOTRP(A,NX,NY,X,Y,XI,YI,AI)
      DIMENSION A(NY,NX),R(4),W(4),X(NX),Y(NY)
C
      SW = 0.
      X0 = X(1)
      DX = X(2) - X(1)
      Y0 = Y(1)
      DY = Y(2) - Y(1)
C
      J1 = 1 +  INT((XI - X0)/DX)
      IF(J1.LE.1) J1 = 1
      IF(J1.GT.NX) J1 = NX
      J2 = J1 + 1
      IF(J1.EQ.1) J2 = 1
      IF(J1.EQ.NX) J2 = NX
C
      K1 = 1 +  INT((YI - Y0)/DY)
      IF(K1.LE.1) K1 = 1
      IF(K1.GT.NY) K1 = NY
      K2 = K1 + 1
      IF(K1.EQ.1) K2 = 1
      IF(K1.EQ.NY) K2 = NY
C
C     WRITE (6,21) X0,DX,XI,Y0,DY,YI
   21 FORMAT (1X,'X0,DX,XI,Y0,DY,YI',6F8.2)
C
C     WRITE (6,20) J1,J2,K1,K2
   20 FORMAT (1X,'J1,J2,K1,K2',4I6)
C
      L = 0
      DO 1 J=J1,J2
      DO 1 K=K1,K2
      L = L + 1
      R(L) = (X(J) - XI)**2 + (Y(K) - YI)**2
      IF(R(L).LT.0.0001) R(L) = 0.0001
      SW = SW + 1/R(L)
    1 CONTINUE
C
      AS = 0.
      L = 0
      DO 2 J=J1,J2
      DO 2 K=K1,K2
      L = L + 1
      AS = AS + A(K,J)/R(L)
     
C     WRITE (6,24) L,J,K,R(L),A(J,K)
   24 FORMAT (1X,'L,J,K,R,A',3I5,5F9.3)
C
    2 CONTINUE
C
      AI = AS/SW
C
      RETURN
      END