%  plotFrancesICandtau;  plot the T/S and wind stress data generated for the 
%  hurricane ocean response test case by the Fortran code hurrtest.f
%  the original wind data are from HWINDS, and thanks to AOML/HRD
%  the wind stress was computed using Powell et al. (2003) Cd
%
%  by Jim Price, January, 2007
%  508-289-2526
%  jprice@whoi.edu
%

set(0,'DefaultTextFontSize',14)
set(0,'DefaultAxesFontSize',14)
set(0,'DefaultAxesLineWidth',1.2)
set(0,'DefaultLineLineWidth',1.2)

clear all
close all

%
%  load and plot T/S profile data
%

load TSinitprofiles.dat;
fort = TSinitprofiles; 
[nz a] = size(fort);

for j=1:nz
    z(j) = fort(j,1);
    t(j) = fort(j,2);
    s(j) = fort(j,3);
end

figure(1)
clf reset
subplot(1,2,1)
plot(t, -z)
xlabel('temperature, C')
ylabel('z, m')
grid on
title('initial T(z) and S(z) from EM-Apex')
%  actually, this is EMApex for the upper 200 m and climatology below! 

subplot(1,2,2)
plot(s, -z)
xlabel('salinity')
grid on


%
%  load and plot the Frances wind stress field calculated by
%  the fortran code
%

load stressfield.dat;    %  wind stress data from hurrtest.f
fort = stressfield;
[ny nx] = size(fort);

x = fort(:,1);
y = fort(:,2);
u = fort(:,3);
v = fort(:,4);
taux = fort(:,5);
tauy = fort(:,6);

figure(20)
clf reset
quiver(x, y, taux, tauy);
xlabel('across-track distance, x, km')
ylabel('along-track distance, y, km')
axis([-250 250 -250 250])
axis('square')
title(' wind stress in storm-centered coordinates')

figure(21)
clf reset
quiver(x, y, u, v);
xlabel('across-track distance, x, km')
ylabel('along-track distance, y, km')
axis([-250 250 -250 250])
axis('square')
title(' wind speed in storm-centered coordinates')

%  pack these data into 2-d arrays

nx = sqrt(length(x));
ny = nx;

k = 0;
for i=1:ny
    for j=1:nx
        k = k + 1;
x2(i,j) = x(k);
y2(i,j) = y(k);
taux2(i,j) = taux(k);
tauy2(i,j) = tauy(k);
u2(i,j) = u(k);
v2(i,j) = v(k);
    end
end

figure(22)
clf reset
spd24 = sqrt(u2.^2 + v2.^2);
[c1, c2] = contour(x2, y2, spd24, [0:10:70]);
clabel(c1, c2);
xlabel('across track, km')
ylabel('along track, km')
axis([-200 200 -200 200])
title('wind speed in storm-centered coordinates')

%  slice across the center of the ocean grid in both directions

xc = -250:10:250;
yc = 0.;
tauxxc = interp2(x2, y2, taux2, xc, yc);
tauyxc = interp2(x2, y2, tauy2, xc, yc);

figure(30)
clf reset
subplot(2,1,1)
plot(xc, tauxxc, xc, tauyxc)
legend('taux', 'tauy'); legend boxoff
ylabel('stress, Pa')
xlabel('across-track distance, x, km')
grid on
title('wind stress across and along the track')
axis([-200 200 -7 7])

clear xc yc
xc = 0;
yc = -250:10:250;
tauxyc = interp2(x2, y2, taux2, xc, yc);
tauyyc = interp2(x2, y2, tauy2, xc, yc);

subplot(2,1,2)
plot(yc, tauxyc, yc, tauyyc)
legend('taux', 'tauy'); legend boxoff
ylabel('stress, Pa')
xlabel('along-track distance, y, km')
grid on
axis([-200 200 -7 7])








